/***********************************************************************************************************************************
S3 Storage File Write
***********************************************************************************************************************************/
#ifndef STORAGE_S3_WRITE_H
#define STORAGE_S3_WRITE_H

#include "storage/s3/storage.intern.h"
#include "storage/write.h"

/***********************************************************************************************************************************
Constructors
***********************************************************************************************************************************/
StorageWrite *storageWriteS3New(StorageS3 *storage, const String *name, size_t partSize);

#endif
